==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/IndexesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.IndexesArgs.builder
import com.pulumi.azurenative.documentdb.kotlin.enums.DataType
import com.pulumi.azurenative.documentdb.kotlin.enums.IndexKind
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The indexes for the path.
 * @property dataType The datatype for which the indexing behavior is applied to.
 * @property kind Indicates the type of index.
 * @property precision The precision of the index. -1 is maximum precision.
 */
public data class IndexesArgs(
    public val dataType: Output<Either<String, DataType>>? = null,
    public val kind: Output<Either<String, IndexKind>>? = null,
    public val precision: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.IndexesArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.IndexesArgs =
        com.pulumi.azurenative.documentdb.inputs.IndexesArgs.builder()
            .dataType(
                dataType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .kind(
                kind?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .precision(precision?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IndexesArgs].
 */
@PulumiTagMarker
public class IndexesArgsBuilder internal constructor() {
    private var dataType: Output<Either<String, DataType>>? = null

    private var kind: Output<Either<String, IndexKind>>? = null

    private var precision: Output<Int>? = null

    /**
     * @param value The datatype for which the indexing behavior is applied to.
     */
    @JvmName("spgkajxgowqctahg")
    public suspend fun dataType(`value`: Output<Either<String, DataType>>) {
        this.dataType = value
    }

    /**
     * @param value Indicates the type of index.
     */
    @JvmName("wfatvnxnjfyusely")
    public suspend fun kind(`value`: Output<Either<String, IndexKind>>) {
        this.kind = value
    }

    /**
     * @param value The precision of the index. -1 is maximum precision.
     */
    @JvmName("wrqkkmigkhvqmdba")
    public suspend fun precision(`value`: Output<Int>) {
        this.precision = value
    }

    /**
     * @param value The datatype for which the indexing behavior is applied to.
     */
    @JvmName("alqmonhdbdsluxjk")
    public suspend fun dataType(`value`: Either<String, DataType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataType = mapped
    }

    /**
     * @param value The datatype for which the indexing behavior is applied to.
     */
    @JvmName("gxsxdlnnggdumond")
    public fun dataType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DataType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataType = mapped
    }

    /**
     * @param value The datatype for which the indexing behavior is applied to.
     */
    @JvmName("aapyhcymiosygwki")
    public fun dataType(`value`: DataType) {
        val toBeMapped = Either.ofRight<String, DataType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataType = mapped
    }

    /**
     * @param value Indicates the type of index.
     */
    @JvmName("fymuntktcxjnshak")
    public suspend fun kind(`value`: Either<String, IndexKind>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Indicates the type of index.
     */
    @JvmName("fuunsoisubcwhhjk")
    public fun kind(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IndexKind>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Indicates the type of index.
     */
    @JvmName("pshfqxppnmsddwep")
    public fun kind(`value`: IndexKind) {
        val toBeMapped = Either.ofRight<String, IndexKind>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value The precision of the index. -1 is maximum precision.
     */
    @JvmName("tqtnpvlxhecabwys")
    public suspend fun precision(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.precision = mapped
    }

    internal fun build(): IndexesArgs = IndexesArgs(
        dataType = dataType,
        kind = kind,
        precision = precision,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/IndexesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.IndexesArgs.builder
import com.pulumi.azurenative.documentdb.kotlin.enums.DataType
import com.pulumi.azurenative.documentdb.kotlin.enums.IndexKind
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The indexes for the path.
 * @property dataType The datatype for which the indexing behavior is applied to.
 * @property kind Indicates the type of index.
 * @property precision The precision of the index. -1 is maximum precision.
 */
public data class IndexesArgs(
    public val dataType: Output<Either<String, DataType>>? = null,
    public val kind: Output<Either<String, IndexKind>>? = null,
    public val precision: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.IndexesArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.IndexesArgs =
        com.pulumi.azurenative.documentdb.inputs.IndexesArgs.builder()
            .dataType(
                dataType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .kind(
                kind?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .precision(precision?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IndexesArgs].
 */
@PulumiTagMarker
public class IndexesArgsBuilder internal constructor() {
    private var dataType: Output<Either<String, DataType>>? = null

    private var kind: Output<Either<String, IndexKind>>? = null

    private var precision: Output<Int>? = null

    /**
     * @param value The datatype for which the indexing behavior is applied to.
     */
    @JvmName("hxxdgoyrbwdcbpyd")
    public suspend fun dataType(`value`: Output<Either<String, DataType>>) {
        this.dataType = value
    }

    /**
     * @param value Indicates the type of index.
     */
    @JvmName("ckljlkxmhhftowrr")
    public suspend fun kind(`value`: Output<Either<String, IndexKind>>) {
        this.kind = value
    }

    /**
     * @param value The precision of the index. -1 is maximum precision.
     */
    @JvmName("aomehpvuonepmyug")
    public suspend fun precision(`value`: Output<Int>) {
        this.precision = value
    }

    /**
     * @param value The datatype for which the indexing behavior is applied to.
     */
    @JvmName("fpheqvtdefvmnkqr")
    public suspend fun dataType(`value`: Either<String, DataType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataType = mapped
    }

    /**
     * @param value The datatype for which the indexing behavior is applied to.
     */
    @JvmName("mxnkxyonyyiepopt")
    public fun dataType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DataType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataType = mapped
    }

    /**
     * @param value The datatype for which the indexing behavior is applied to.
     */
    @JvmName("uodeydkdqpmghswc")
    public fun dataType(`value`: DataType) {
        val toBeMapped = Either.ofRight<String, DataType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataType = mapped
    }

    /**
     * @param value Indicates the type of index.
     */
    @JvmName("pbxdipjocbktrrgp")
    public suspend fun kind(`value`: Either<String, IndexKind>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Indicates the type of index.
     */
    @JvmName("xtvnbcfhsybvglak")
    public fun kind(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IndexKind>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Indicates the type of index.
     */
    @JvmName("abymswqplxstknlo")
    public fun kind(`value`: IndexKind) {
        val toBeMapped = Either.ofRight<String, IndexKind>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value The precision of the index. -1 is maximum precision.
     */
    @JvmName("axvlhpwckbqaywqi")
    public suspend fun precision(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.precision = mapped
    }

    internal fun build(): IndexesArgs = IndexesArgs(
        dataType = dataType,
        kind = kind,
        precision = precision,
    )
}
